# Overview

## `secret`: a [Rune](https://github.com/google/rune)-style type for sensitive values in Python

<!-- prettier-ignore -->
::: secret_type
    options:
      members: false
      show_root_toc_entry: false
